==> was-plugin-3.5.0-sources.jar: com/xebialabs/deployit/plugin/was/container/NodeAgent.java <==
/*
 * Copyright (c) 2008-2011 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.was.container;

import static com.google.common.collect.Maps.newHashMap;

import java.util.Collections;
import java.util.Map;
import java.util.Set;

import com.xebialabs.deployit.plugin.api.inspection.Inspect;
import com.xebialabs.deployit.plugin.api.inspection.InspectionPlanningContext;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.api.udm.base.BaseConfigurationItem;
import com.xebialabs.deployit.plugin.python.PythonInspectionStep;
import com.xebialabs.deployit.plugin.python.PythonManagingContainer;

@SuppressWarnings("serial")
@Metadata(description = "A WebSphere node agent.")
public class NodeAgent extends BaseConfigurationItem implements Node {

	@Property(required = true, asContainment = true, label = "Deployment manager that manages this node agent")
	private DeploymentManager cell;

	@Property(required = true, defaultValue = "was/base/synchronize-node.py", hidden = true)
	private String synchronizeScript;

	public DeploymentManager getCell() {
		return cell;
	}

	public void setCell(DeploymentManager cell) {
		this.cell = cell;
	}

	@Override
	public PythonManagingContainer getManagingContainer() {
		return getCell();
	}

	@Override
	public String getCellName() {
		return getCell().getCellName();
	}

	@Override
	public Set<Node> getNodes() {
		return Collections.singleton((Node) this);
	}

	public String getNodeName() {
		return getName();
	}

	public String getSynchronizeScript() {
    	return synchronizeScript;
    }

	public void setSynchronizeScript(String synchronizeScript) {
    	this.synchronizeScript = synchronizeScript;
    }

	@Override
    public String getContainmentPath() {
	    return "/Node:" + getName();
    }

	@Override
	public String getShortTypeDescription() {
		return "node";
	}

	@Override
	public String getWasConfigIdType() {
		return "Node";
	}

	@Override
	public String getWasTargetType() {
		return "Node";
	}

	@Inspect
	public void inspect(InspectionPlanningContext ctx) {
		Map<String, Object> pythonVars = newHashMap();
		pythonVars.put("container", this);
		ctx.addStep(new PythonInspectionStep(this, this.getManagingContainer(), "was/container/inspect-node-agent.py", pythonVars, "Inspect " + this));
	}

}

==> was-plugin-3.7.0-sources.jar: com/xebialabs/deployit/plugin/was/container/NodeAgent.java <==
/*
 * Copyright (c) 2008-2011 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.was.container;

import static com.google.common.collect.Maps.newHashMap;

import java.util.Collections;
import java.util.Map;
import java.util.Set;

import com.xebialabs.deployit.plugin.api.inspection.Inspect;
import com.xebialabs.deployit.plugin.api.inspection.InspectionPlanningContext;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.api.udm.base.BaseContainer;
import com.xebialabs.deployit.plugin.python.PythonInspectionStep;
import com.xebialabs.deployit.plugin.python.PythonManagingContainer;

@SuppressWarnings("serial")
@Metadata(description = "A WebSphere node agent.")
public class NodeAgent extends BaseContainer implements Node {

	@Property(required = true, asContainment = true, label = "Deployment manager that manages this node agent")
	private DeploymentManager cell;

	@Property(required = true, defaultValue = "was/base/synchronize-node.py", hidden = true)
	private String synchronizeScript;
	
	public DeploymentManager getCell() {
		return cell;
	}

	public void setCell(DeploymentManager cell) {
		this.cell = cell;
	}

	@Override
	public PythonManagingContainer getManagingContainer() {
		return getCell();
	}

	@Override
	public String getCellName() {
		return getCell().getCellName();
	}

	@Override
	public Set<Node> getNodes() {
		return Collections.singleton((Node) this);
	}

	public String getNodeName() {
		return getName();
	}

	public String getSynchronizeScript() {
    	return synchronizeScript;
    }

	public void setSynchronizeScript(String synchronizeScript) {
    	this.synchronizeScript = synchronizeScript;
    }

	@Override
    public String getContainmentPath() {
	    return "/Node:" + getName();
    }

	@Override
	public String getShortTypeDescription() {
		return "node";
	}

	@Override
	public String getWasConfigIdType() {
		return "Node";
	}

	@Override
	public String getWasTargetType() {
		return "Node";
	}
	
	@Inspect
	public void inspect(InspectionPlanningContext ctx) {
		Map<String, Object> pythonVars = newHashMap();
		pythonVars.put("container", this);
		ctx.addStep(new PythonInspectionStep(this, this.getManagingContainer(), "was/container/inspect-node-agent.py", pythonVars, "Inspect " + this));
	}

}
